package com.rf.check.user.rest;

import com.alibaba.fastjson.JSONObject;
import com.google.gson.Gson;
import com.rf.check.base.rest.BaseController;
import com.rf.check.picture.dao.model.PictureEntity;
import com.rf.check.picture.service.PictureService;
import com.rf.check.security.SafetyProcess;
import com.rf.check.user.dao.model.UserEntity;
import com.rf.check.user.dao.model.UserPictureEntity;
import com.rf.check.user.service.UserPictureService;
import com.rf.check.user.service.UserService;
import com.rf.check.utils.Constant;
import com.rf.check.utils.DateUtil;
import com.rf.check.utils.JWTUtil;
import com.rf.check.utils.Result;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.io.FileUtils;
import org.apache.http.HttpResponse;
import org.apache.http.client.HttpClient;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.util.EntityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Random;

/**
 * @Description: 用户生成图片等相关接口
 * @Author: zsy
 * @Date: 2024/12/4
 */
@RestController
@RequestMapping("/userPicture")
@Api(tags = "用户生成图片等相关接口")
@Slf4j
public class UserPictureController extends BaseController {

    @Autowired
    private UserPictureService userPictureService;

    @Autowired
    private PictureService pictureService;

    @PostMapping("/savePicture")
    @ApiOperation(value = "保存生成图片记录", notes = "参数：json对象；userId：用户ID；pictureUrl：图片URL；pictureId：图片ID")
    public Result savePicture(@RequestBody String json) {
        UserPictureEntity userPictureEntity = JSONObject.parseObject(json, UserPictureEntity.class);
        userPictureEntity.setCreateTime(DateUtil.getNowTime());
        userPictureEntity.setUpdateTime(DateUtil.getNowTime());
        userPictureEntity = this.userPictureService.save(userPictureEntity);
        PictureEntity pictureEntity = this.pictureService.findById(userPictureEntity.getPictureId());
        if (pictureEntity != null){
            pictureEntity.setShareNum(pictureEntity.getShareNum() + 1);
            pictureEntity.setUpdateTime(DateUtil.getNowTime());
            this.pictureService.save(pictureEntity);
        }
        return success(userPictureEntity);
    }

    @GetMapping("/findUserPictureList")
    @ApiOperation(value = "生成图片记录列表查询", notes = "参数包括：beginNum:页码，pageSize：每页条数，userId：用户ID")
    public Result findUserPictureList(String userId, int beginNum, int pageSize) {
        Page<UserPictureEntity> userPictureEntities = this.userPictureService.findUserPictureList(userId, beginNum, pageSize);
        return success(userPictureEntities);
    }

}
